@@ -36,7 +36,7 @@ class UserService(object):
     _USER_ENTERPRISE = 'api/rest/v1/user/{}/enterprise'
     _USER_CUSTOM_FIELDS = 'api/rest/v1/user/{}/customfields'
     _PASSWORD_REQUIREMENTS = 'api/rest/v1/user/{}/password/requirements'
-    _STRONG_ID = 'api/rest/v1/user/{}/strongidentification'
+    _STRONG_IDENTIFICATION = 'api/rest/v1/user/{}/strongidentification'
     _STRONG_ID_HISTORIES = 'api/rest/v1/user/{}/strongidentification/history'
     _STRONG_ID_HISTORY = 'api/rest/v1/user/{}/strongidentification/history/{}'
     _PASSWORD = 'api/rest/v1/user/{}/password'
@@ -92,21 +92,15 @@ class UserService(object):
                                      response.status_code)
 
     def create(self,
-               users,
+               user,
                password_length=15,
-               password=None,
-               email_verification=False,
-               mobile_verification=False):
+               password=None):
         '''Create new user.
         Args:
-            users (User, list)         : user or a list of users to create.
+            user (User, list)         : user create.
             password_length (int)      : length of the generated password
             password (str)             : if None, password will be randomly
                                          generated.
-            email_verification (bool)  : send email verification after creating
-                                         a user account.
-            mobile_verification (bool) : send mobile verification after creating
-                                         a user account.
         Returns:
             New user object and user's password.
         Raises:
@@ -114,74 +108,33 @@ class UserService(object):
             TrivoreIDSDKException if the type of the User is wrong or namespace
                                   code was not defined
         '''
-        if 'User' not in str(type(users)) and type(users) != list:
+        if 'User' not in str(type(user)) and type(user) != list:
             raise TrivoreIDSDKException('User type is wrong!')
-        elif type(users) == list:
-            for u in users:
-                if 'User' not in str(type(u)):
-                    raise TrivoreIDSDKException('User type is wrong!')
 
-        if type(users) != list:
-            users = [users]
+        if password is None:
+            pattern = string.ascii_letters + string.digits
+            password = ''
+            # to avoid repeating letters
+            for i in range (int(password_length/2)):
+                password += ''.join(random.sample(pattern, 2))
+            if password_length % 2 == 1:
+                password += random.sample(pattern, 1)[0]
 
-        result = []
+        user.password = password
 
-        for user in users:
+        uri = su.uri(self._server, self._USERS)
+        response = self._session.post(uri, json=user.serialize(),
+                                           headers=self._header,
+                                           auth=self._auth)
 
-            if password is None:
-                pattern = string.ascii_letters + string.digits
-                password = ''
-                # to avoid repeating letters
-                for i in range (int(password_length/2)):
-                    password += ''.join(random.sample(pattern, 2))
-                if password_length % 2 == 1:
-                    password += random.sample(pattern, 1)[0]
-
-            user.password = password
-            if bool(user.memberOf):
-                user.memberOf = self._check_groups(user.memberOf, user.nsCode)
-
-            uri = su.uri(self._server, self._USERS)
-            response = self._session.post(uri, json=user.serialize(),
-                                               headers=self._header,
-                                               auth=self._auth)
-
-            if response.status_code == 201:
-                usr = User(response.json())
-                logging.debug('Successfully created user with id {}'.format(
-                                    usr.id))
-                fails = []
-                if email_verification:
-                    logging.debug('Sending email verification to the user email(s)')
-                    for email in usr.emails.emails:
-                        try:
-                            self.verify_email(usr.id, email.email['address'])
-                        except TrivoreIDException as e:
-                            fails.append(e.args[0])
-
-                if mobile_verification:
-                    logging.debug('Sending mobile verification to the user mobile(s)')
-                    for mobile in usr.mobiles.mobiles:
-                        try:
-                            self.verify_sms_link(usr.id,
-                                                 mobile['number'])
-                        except TrivoreIDException as e:
-                            fails.append(e.args[0])
-
-                if len(fails) > 0:
-                    raise TrivoreIDException(', '.join(fails))
-
-                usr.password = password
-                result.append(usr)
-
-            else:
-                raise TrivoreIDException(su.error_response_message(response),
-                                         response.status_code)
-
-        if len(result) == 1:
-            return result[0]
+        if response.status_code == 201:
+            user = User(response.json())
+            logging.debug('Successfully created user with id {}'.format(
+                                user.id))
+            return user
         else:
-            return result
+            raise TrivoreIDException(su.error_response_message(response),
+                                     response.status_code)
 
     def get(self, userId):
         '''Get a single user by id.
@@ -221,7 +174,6 @@ class UserService(object):
         # removing user's password
         user.password = None
 
-        user.memberOf = self._check_groups(user.memberOf, user.nsCode)
         if userId is None:
             userId = user.id
 
@@ -280,7 +232,9 @@ class UserService(object):
                      userId,
                      email=None,
                      return_url=None,
-                     expiration_days=7):
+                     expiration_days=7,
+                     emailTemplateId=None,
+                     emailTemplateProperties=None):
         '''
         Send request to verify user's email address.
         Args:
@@ -290,6 +244,12 @@ class UserService(object):
                                identification service front page.
             expiration_days (int) : If not specified, current policies or
                                     default value is used.
+            emailTemplateId (str) : If a valid email template ID is given, the
+                                    template will be used as message content.
+                                    Email verification message template can use
+                                    the following supported properties.
+           emailTemplateProperties (dict) : Additional email template properties
+                                            if email template is used.
         '''
         request_body = {}
         if email is not None:
@@ -298,6 +258,10 @@ class UserService(object):
             request_body['returnURL'] = return_url
         if expiration_days is not None:
             request_body['expirationDays'] = expiration_days
+        if emailTemplateId is not None:
+            request_body['emailTemplateId'] = emailTemplateId
+        if emailTemplateProperties is not None:
+            request_body['emailTemplateProperties'] = emailTemplateProperties
 
         uri = su.uri(self._server, self._USER_EMAIL_VERIFY).format(userId)
         response = self._session.post(uri, json=request_body,
@@ -305,8 +269,8 @@ class UserService(object):
                                            auth=self._auth)
 
         if response.status_code is 204:
-            logging.debug('Successfully sent the email verification request to the' +
-                            ' user with id {}'.format(userId))
+            logging.debug('Successfully sent the email verification request ' +
+                            'to the user with id {}'.format(userId))
         else:
             raise TrivoreIDException(su.error_response_message(response),
                                      response.status_code)
@@ -404,10 +368,6 @@ class UserService(object):
         if 'Invite' not in str(type(invite)):
             raise TrivoreIDSDKException('Invite type is wrong!')
 
-        invite.request_body['groups'] = self._check_groups(
-                                                invite.request_body['groups'],
-                                                invite.request_body['nsCode'])
-
         uri = su.uri(self._server, self._INVITE_USER)
         response = self._session.post(uri, json=invite.request_body,
                                            headers=self._header,
@@ -561,7 +521,7 @@ class UserService(object):
         Raises:
             TrivoreIDException if the status code is not 200.
         '''
-        uri = su.uri(self._server, self._STRONG_ID).format(userId)
+        uri = su.uri(self._server, self._STRONG_IDENTIFICATION).format(userId)
         response = self._session.get(uri, headers=self._header,
                                           auth=self._auth)
 
@@ -584,7 +544,7 @@ class UserService(object):
         Raises:
             TrivoreIDException if the status code is not 200.
         '''
-        uri = su.uri(self._server, self._STRONG_ID).format(userId)
+        uri = su.uri(self._server, self._STRONG_IDENTIFICATION).format(userId)
 
         data = { 'personalId' : personalId, 'remarks' : remarks }
 
@@ -952,45 +912,3 @@ class UserService(object):
         else:
             raise TrivoreIDException(su.error_response_message(response),
                                      response.status_code)
-
-    def _check_groups(self,
-                      groups,
-                      nsCode):
-        '''
-        Replace corresponding group names with their ids.
-        Args:
-            groups (list)             : group list
-            nsCode (srt)              : namespace code
-            include_supervisor (bool) : if supervisor should be included. If
-                                        False, excludes it from the list.
-        Returns:
-            New list with group ids.
-        '''
-
-        # get all groups
-        all_groups = self._group_service.get_all(
-                            Filter(Filter.EQUAL, 'nsCode', nsCode)).resources
-
-        for i in range(len(groups)):
-            # if name of the group in the list - get this group id
-            is_name = False
-            is_id = False
-            for group in all_groups:
-                if group.name == groups[i]:
-                    is_name = True
-                elif group.id == groups[i]:
-                    is_id = True
-            if is_name:
-                group = self._group_service.get_all(Filter().and_filters(
-                            Filter(Filter.EQUAL, 'name', groups[i]),
-                            Filter(Filter.EQUAL, 'nsCode', nsCode)
-                        )).resources[0]
-                groups[i] = group.id
-            elif not is_id:
-                group = self._group_service.create(Group({
-                            'name' : groups[i],
-                            'nsCode' : nsCode
-                    }))
-                groups[i] = group.id
-
-        return groups
